from django.contrib import admin
from . import models as ohm2_countries_light_models

"""
class ModelAdmin(admin.ModelAdmin):
	pass

admin.site.register(ohm2_countries_light_models.Model, ModelAdmin)
"""