# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-08-01 04:07
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models
import django.utils.timezone
import ohm2_countries_light.managers


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Country',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('identity', models.CharField(max_length=2048, unique=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now)),
                ('last_update', models.DateTimeField(default=django.utils.timezone.now)),
                ('name', models.CharField(max_length=512, validators=[django.core.validators.MinLengthValidator(1)])),
                ('official_name', models.CharField(max_length=512, validators=[django.core.validators.MinLengthValidator(1)])),
                ('alpha_2', models.CharField(max_length=64, validators=[django.core.validators.MinLengthValidator(2)])),
                ('alpha_3', models.CharField(max_length=64, validators=[django.core.validators.MinLengthValidator(3)])),
                ('numeric', models.IntegerField()),
                ('flag_small', models.ImageField(upload_to=ohm2_countries_light.managers.country_flag_small_upload_to)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
